#[non_exhaustive]pub enum Directive {
Claim,
Execute(Pact),
Settle(Retainer, Outcome),
Idle,
}Expand description
An instruction the kernel issues for a runtime to perform.
#[non_exhaustive]: this advanced-tier protocol may gain directives, so a
runtime’s match must carry a wildcard arm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Claim
Claim a pact from the runtime’s configured dockets.
Execute(Pact)
Execute the given claimed pact.
Settle(Retainer, Outcome)
Settle the claim identified by the retainer with the decided outcome.
Idle
Nothing remains to be performed for this step.